@@ -122,7 +122,7 @@ class DiscreteEnv(gym.Env):
     #set placeholder for infos
     info ={}        
      
-    return self.state, reward, theta_updated , done, {}
+    return self.state, reward, done, theta_updated , {}
 
 #reset state and horizon    
   def reset(self):
